# galaxy-update

> Update dependencies in `requirements.yml`

[![PyPI: Version](https://img.shields.io/pypi/v/galaxy-update?logo=pypi&logoColor=white)](https://pypi.org/project/galaxy-update)
[![GitHub: Release](https://img.shields.io/github/v/release/deadnews/galaxy-update?logo=github&logoColor=white)](https://github.com/deadnews/galaxy-update/releases/latest)
[![CI: pre-commit](https://results.pre-commit.ci/badge/github/deadnews/galaxy-update/main.svg)](https://results.pre-commit.ci/latest/github/deadnews/galaxy-update/main)
[![CI: Main](https://img.shields.io/github/actions/workflow/status/deadnews/galaxy-update/main.yml?branch=main&logo=github&logoColor=white&label=main)](https://github.com/deadnews/galaxy-update/actions/workflows/main.yml)
[![CI: Coverage](https://img.shields.io/codecov/c/github/deadnews/galaxy-update?token=OCZDZIYPMC&logo=codecov&logoColor=white)](https://app.codecov.io/gh/deadnews/galaxy-update)

## Installation

```sh
pip install galaxy-update
# or
pipx install galaxy-update
```
